.. BayesMBAR documentation master file, created by
   sphinx-quickstart on Fri Mar  8 13:56:32 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to BayesMBAR
====================

BayesMBAR stands for `Bayesian Multistate Bennett Acceptance Ratio methods <https://pubs.acs.org/doi/full/10.1021/acs.jctc.3c01212>`_. 
It is a Bayesian generalization of the Multistate Bennett Acceptance Ratio (MBAR) method. 
The MBAR method is a very useful for estimating free energy differences between multiple states from molecular dynamics simulations or Monte Carlo sampling.
BayesMBAR generalizes the MBAR method by providing a Bayesian framework for estimating free energy differences and their uncertainties. 
This package provides a Python implementation of the BayesMBAR method.

.. toctree::
   :maxdepth: 2

   installation
   examples
